@@ -1,12 +1,15 @@
-from AsteriskRealtimeData.application.queue_member_repository import (
-    QueueMemberRepository,
-)
+from typing import List
+from datetime import datetime
 from antidote import inject, Provide
+
+from AsteriskRealtimeData.domain.mascara_ipaddress.mascara_ipaddress_vo import MascaraIpaddressVo
+from AsteriskRealtimeData.shared.errors.data_not_found_error import DataNotFound
+from AsteriskRealtimeData.domain.queue_member.queue_member_search_criteria_vo import QueueMemberSearchCriteriaVo
+from AsteriskRealtimeData.domain.queue_member.queue_member_update_vo import QueueMemberUpdateVo
+from AsteriskRealtimeData.application.queue_member_repository import QueueMemberRepository
 from AsteriskRealtimeData.domain.queue_member.queue_member import QueueMember
 from AsteriskRealtimeData.domain.queue_member.queue_member_vo import QueueMemberVo
-from AsteriskRealtimeData.application.mascara_ipaddress_service import (
-    MascaraIpaddressService,
-)
+from AsteriskRealtimeData.application.mascara_ipaddress_service import MascaraIpaddressService
 
 
 class QueueMemberService:
@@ -14,12 +17,12 @@ class QueueMemberService:
     def create_queue_member(
         self, queue_member_vo: QueueMemberVo, repository: Provide[QueueMemberRepository]
     ) -> QueueMemberVo:
+        try:
+            mascara_ipaddress = MascaraIpaddressService().get_mascara_ipaddress(queue_member_vo.ipaddress)
+        except DataNotFound:
+            mascara_ipaddress = MascaraIpaddressVo(ipaddress="0.0.0.0", lastconnection=datetime.now())
 
-        mascara_ipaddress = MascaraIpaddressService().get_mascara_ipaddress(
-            queue_member_vo.ipaddress
-        )
-
-        is_queue_member = mascara_ipaddress.ipaddress
+        is_queue_member = mascara_ipaddress.ipaddress == queue_member_vo.ipaddress
 
         queue_member = QueueMember(
             peer=queue_member_vo.peer,
@@ -30,7 +33,7 @@ class QueueMemberService:
             is_queuemember=is_queue_member,
         )
 
-        repository.save(queue_member, {"ipaddress": queue_member_vo.ipaddress})
+        repository.save(queue_member, {"peer": queue_member_vo.peer})
 
         return QueueMemberVo(
             peer=queue_member_vo.peer,
@@ -41,10 +44,25 @@ class QueueMemberService:
             is_queuemember=is_queue_member,
         )
 
+    @inject
+    def update_queue_member(
+        self, queue_member_update_vo: QueueMemberUpdateVo, repository: Provide[QueueMemberRepository]
+    ) -> QueueMemberVo:
+        repository.update(queue_member_update_vo)
+
+        queue_member_dict = repository.get_by_criteria(queue_member_update_vo.get_key_field())
+
+        return QueueMemberVo(
+            peer=queue_member_dict["peer"],
+            actual_status=queue_member_dict["actual_status"],
+            ipaddress=queue_member_dict["ipaddress"],
+            membername=queue_member_dict["membername"],
+            last_status_datetime=queue_member_dict["last_status_datetime"],
+            is_queuemember=queue_member_dict["is_queuemember"],
+        )
+
     @inject()
-    def list_queue_member(
-        self, repository: Provide[QueueMemberRepository]
-    ) -> list[QueueMemberVo]:
+    def queue_member_list(self, repository: Provide[QueueMemberRepository]) -> List[QueueMemberVo]:
         result: list = []
         for document in repository.list():
             result.append(
@@ -60,9 +78,7 @@ class QueueMemberService:
         return result
 
     @inject
-    def get_queue_member(
-        self, peer: str, repository: Provide[QueueMemberRepository]
-    ) -> QueueMemberVo:
+    def get_queue_member(self, peer: str, repository: Provide[QueueMemberRepository]) -> QueueMemberVo:
         queue_member = repository.get_by_criteria({"peer": peer})
         return QueueMemberVo(
             peer=queue_member["peer"],
@@ -75,9 +91,9 @@ class QueueMemberService:
 
     @inject
     def get_by_search_criteria(
-        self, search_criteria: dict, repository: Provide[QueueMemberRepository]
+        self, search_criteria: QueueMemberSearchCriteriaVo, repository: Provide[QueueMemberRepository]
     ) -> QueueMemberVo:
-        queue_member = repository.get_by_criteria(search_criteria)
+        queue_member = repository.get_by_criteria(search_criteria.as_dict())
         return QueueMemberVo(
             peer=queue_member["peer"],
             actual_status=queue_member["actual_status"],
@@ -88,15 +104,5 @@ class QueueMemberService:
         )
 
     @inject
-    def delete_queue_member(
-        self, peer: str, repository: Provide[QueueMemberRepository]
-    ) -> QueueMemberVo:
+    def delete_queue_member(self, peer: str, repository: Provide[QueueMemberRepository]) -> None:
         repository.delete_by_criteria({"peer": peer})
-        return QueueMemberVo(
-            peer=peer,
-            actual_status="",
-            ipaddress="",
-            membername="",
-            last_status_datetime="",
-            is_queuemember="",
-        )
