@@ -3,7 +3,7 @@ from dataclasses import dataclass
 
 @dataclass
 class QueueStatusVo:
-    status_code: int
+    status_code: str
     description: str
 
     def as_dict(self) -> dict:
